==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterProxyMatchFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterProxyMatchFluent<A extends EnvoyFilterProxyMatchFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterProxyMatchFluent() {
  }
  public EnvoyFilterProxyMatchFluent(EnvoyFilterProxyMatch instance) {
    instance = (instance != null ? instance : new EnvoyFilterProxyMatch());

    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withProxyVersion(instance.getProxyVersion());
      this.withMetadata(instance.getMetadata());
      this.withProxyVersion(instance.getProxyVersion());
    }
  }
  private Map<String,String> metadata;
  private String proxyVersion;
  public A addToMetadata(String key,String value) {
    if(this.metadata == null && key != null && value != null) { this.metadata = new LinkedHashMap(); }
    if(key != null && value != null) {this.metadata.put(key, value);} return (A)this;
  }
  public A addToMetadata(Map<String,String> map) {
    if(this.metadata == null && map != null) { this.metadata = new LinkedHashMap(); }
    if(map != null) { this.metadata.putAll(map);} return (A)this;
  }
  public A removeFromMetadata(String key) {
    if(this.metadata == null) { return (A) this; }
    if(key != null && this.metadata != null) {this.metadata.remove(key);} return (A)this;
  }
  public A removeFromMetadata(Map<String,String> map) {
    if(this.metadata == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.metadata != null){this.metadata.remove(key);}}} return (A)this;
  }
  public Map<String,String> getMetadata() {
    return this.metadata;
  }
  public <K,V>A withMetadata(Map<String,String> metadata) {
    if (metadata == null) { this.metadata =  null;} else {this.metadata = new LinkedHashMap(metadata);} return (A) this;
  }
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  public String getProxyVersion() {
    return this.proxyVersion;
  }
  public A withProxyVersion(String proxyVersion) {
    this.proxyVersion=proxyVersion; return (A) this;
  }
  public boolean hasProxyVersion() {
    return this.proxyVersion != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterProxyMatchFluent that = (EnvoyFilterProxyMatchFluent) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(proxyVersion, that.proxyVersion)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  proxyVersion,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null && !metadata.isEmpty()) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (proxyVersion != null) { sb.append("proxyVersion:"); sb.append(proxyVersion); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterProxyMatchFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EnvoyFilterProxyMatchFluent<A extends EnvoyFilterProxyMatchFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterProxyMatchFluent() {
  }
  
  public EnvoyFilterProxyMatchFluent(EnvoyFilterProxyMatch instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> metadata;
  private String proxyVersion;
  
  protected void copyInstance(EnvoyFilterProxyMatch instance) {
    instance = (instance != null ? instance : new EnvoyFilterProxyMatch());
  
    if (instance != null) {
        this.withMetadata(instance.getMetadata());
        this.withProxyVersion(instance.getProxyVersion());
        this.withMetadata(instance.getMetadata());
        this.withProxyVersion(instance.getProxyVersion());
      }
  }
  
  public A addToMetadata(String key,String value) {
    if(this.metadata == null && key != null && value != null) { this.metadata = new LinkedHashMap(); }
    if(key != null && value != null) {this.metadata.put(key, value);} return (A)this;
  }
  
  public A addToMetadata(Map<String,String> map) {
    if(this.metadata == null && map != null) { this.metadata = new LinkedHashMap(); }
    if(map != null) { this.metadata.putAll(map);} return (A)this;
  }
  
  public A removeFromMetadata(String key) {
    if(this.metadata == null) { return (A) this; }
    if(key != null && this.metadata != null) {this.metadata.remove(key);} return (A)this;
  }
  
  public A removeFromMetadata(Map<String,String> map) {
    if(this.metadata == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.metadata != null){this.metadata.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getMetadata() {
    return this.metadata;
  }
  
  public <K,V>A withMetadata(Map<String,String> metadata) {
    if (metadata == null) { this.metadata =  null;} else {this.metadata = new LinkedHashMap(metadata);} return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public String getProxyVersion() {
    return this.proxyVersion;
  }
  
  public A withProxyVersion(String proxyVersion) {
    this.proxyVersion=proxyVersion; return (A) this;
  }
  
  public boolean hasProxyVersion() {
    return this.proxyVersion != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterProxyMatchFluent that = (EnvoyFilterProxyMatchFluent) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
  
    if (!java.util.Objects.equals(proxyVersion, that.proxyVersion)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(metadata,  proxyVersion,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null && !metadata.isEmpty()) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (proxyVersion != null) { sb.append("proxyVersion:"); sb.append(proxyVersion); }
    sb.append("}");
    return sb.toString();
  }
  

}
